emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r109089: Adapt the MS-DOS build to th


From: Eli Zaretskii
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r109089: Adapt the MS-DOS build to the latest configury changes.
Date: Sat, 14 Jul 2012 13:08:14 +0300
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 109089 [merge]
committer: Eli Zaretskii <address@hidden>
branch nick: trunk
timestamp: Sat 2012-07-14 13:08:14 +0300
message:
  Adapt the MS-DOS build to the latest configury changes.
  
   msdos/sed1v2.inp: In the recipe for $(leimdir)/leim-list.el, edit the
   prerequisites to be "temacs$(EXEEXT) $(BOOTSTRAPEMACS)", to avoid
   the need to rebuild $(bootstrap_exe), which requires a Unixy shell
   via lisp/Makefile.in's "update-subdirs" command.
   msdos/sedlibmk.inp (am_libgnu_a_OBJECTS): Adjust the removal of
   careadlinkat.$(OBJEXT) to the changes in lib/Makefile.in.
   msdos/sed2v2.inp (DATA_START, GC_SETJMP_WORKS, HAVE_MENUS)
   (HAVE_MOUSE): Edit for DJGPP, according to what was previously
   done on src/s/msdos.h.
   msdos/gmalloc.c (GMALLOC_INHIBIT_VALLOC): Don't reference.
   src/s/msdos.h (BSD_SYSTEM, DATA_START, GC_SETJMP_WORKS, HAVE_MOUSE)
   (HAVE_MENUS): Don't define, defined by editing config.in with
   msdos/sed2v2.inp.
   (GMALLOC_INHIBIT_VALLOC): Don't define.
   (MODE_LINE_BINARY_TEXT): Remove, not used anymore.
modified:
  msdos/ChangeLog
  msdos/sed1v2.inp
  msdos/sed2v2.inp
  msdos/sedlibmk.inp
  src/ChangeLog
  src/gmalloc.c
  src/s/msdos.h
=== modified file 'msdos/ChangeLog'
--- a/msdos/ChangeLog   2012-07-14 02:08:32 +0000
+++ b/msdos/ChangeLog   2012-07-14 10:03:30 +0000
@@ -1,3 +1,17 @@
+2012-07-14  Eli Zaretskii  <address@hidden>
+
+       * sed1v2.inp: In the recipe for $(leimdir)/leim-list.el, edit the
+       prerequisites to be "temacs$(EXEEXT) $(BOOTSTRAPEMACS)", to avoid
+       the need to rebuild $(bootstrap_exe), which requires a Unixy shell
+       via lisp/Makefile.in's "update-subdirs" command.
+
+       * sedlibmk.inp (am_libgnu_a_OBJECTS): Adjust the removal of
+       careadlinkat.$(OBJEXT) to the changes in lib/Makefile.in.
+
+       * sed2v2.inp (DATA_START, GC_SETJMP_WORKS, HAVE_MENUS)
+       (HAVE_MOUSE): Edit for DJGPP, according to what was previously
+       done on src/s/msdos.h.
+
 2012-06-30  Eli Zaretskii  <address@hidden>
 
        * mainmake.v2 (bootstrap-clean): Do a maintainer-clean in lib, not

=== modified file 'msdos/sed1v2.inp'
--- a/msdos/sed1v2.inp  2012-06-30 15:32:51 +0000
+++ b/msdos/sed1v2.inp  2012-07-14 10:03:30 +0000
@@ -136,11 +136,13 @@
 /^.\$(libsrc)\/make-doc/s!>.*$!!
 /^     [       ]*\$(libsrc)\/make-docfile /s!`[^`]*`!$(lisp); cd ../src!
 /^[   ]*$/d
+/^\$(leimdir)\/leim-list.el: /s/bootstrap-emacs\$(EXEEXT)/temacs$(EXEEXT) 
$(BOOTSTRAPEMACS)/
 /^     if test -f/,/^  fi$/c\
        command.com /c if exist .gdbinit rm -f _gdbinit
 /^      *test "X\$(PAXCTL)" = X/d
 /^      *test "\$(CANNOT_DUMP)" = "yes"/d
 /^     if test "\$(CANNOT_DUMP)" =/,/^ else /d
+/^     -\{0,1\} *ln -/s/bootstrap-emacs\$(EXEEXT).*$/bootstrap-emacs$(EXEEXT)/
 /^     fi/d
 /^      *LC_ALL=C \$(RUN_TEMACS)/i\
        stubedit temacs.exe minstack=1024k

=== modified file 'msdos/sed2v2.inp'
--- a/msdos/sed2v2.inp  2012-06-30 15:32:51 +0000
+++ b/msdos/sed2v2.inp  2012-07-14 10:03:30 +0000
@@ -54,6 +54,10 @@
 /^#undef HAVE_STRUCT_TM_TM_ZONE *$/s/^.*$/#define HAVE_STRUCT_TM_TM_ZONE 1/
 /^#undef HAVE_SYNC *$/s/^.*$/#define HAVE_SYNC 1/
 /^#undef HAVE___BUILTIN_UNWIND_INIT *$/s/^.*$/#define 
HAVE___BUILTIN_UNWIND_INIT 1/
+/^#undef HAVE_MENUS *$/s/^.*$/#define HAVE_MENUS 1/
+/^#undef HAVE_MOUSE *$/s/^.*$/#define HAVE_MOUSE 1/
+/^#undef DATA_START/s/^.*$/#define DATA_START (\&etext + 1)/
+/^#undef GC_SETJMP_WORKS/s/^.*$/#define GC_SETJMP_WORKS 1/
 /^#undef ORDINARY_LINK/s/^.*$/#define ORDINARY_LINK 1/
 /^#undef PACKAGE_BUGREPORT/s/^.*$/#define PACKAGE_BUGREPORT ""/
 /^#undef PACKAGE_NAME/s/^.*$/#define PACKAGE_NAME ""/

=== modified file 'msdos/sedlibmk.inp'
--- a/msdos/sedlibmk.inp        2012-06-30 15:32:51 +0000
+++ b/msdos/sedlibmk.inp        2012-07-14 10:03:30 +0000
@@ -605,7 +605,9 @@
   s| *sys/select\.h||
   s| *sys/time\.h||
 }
-/^am_libgnu_a_OBJECTS *=/s/careadlinkat\.\$(OBJEXT)//
+/^am_libgnu_a_OBJECTS *=/,/^[  ]/{
+  s/careadlinkat\.\$(OBJEXT) //
+}
 /^am_libgnu_a_OBJECTS *=/s/allocator\.\$(OBJEXT)//
 /^srcdir *=/s/@address@hidden@/./
 /^top_srcdir *=/s/@address@hidden@/../

=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2012-07-14 02:26:31 +0000
+++ b/src/ChangeLog     2012-07-14 10:03:30 +0000
@@ -1,3 +1,13 @@
+2012-07-14  Eli Zaretskii  <address@hidden>
+
+       * gmalloc.c (GMALLOC_INHIBIT_VALLOC): Don't reference.
+
+       * s/msdos.h (BSD_SYSTEM, DATA_START, GC_SETJMP_WORKS, HAVE_MOUSE)
+       (HAVE_MENUS): Don't define, defined by editing config.in with
+       msdos/sed2v2.inp.
+       (GMALLOC_INHIBIT_VALLOC): Don't define.
+       (MODE_LINE_BINARY_TEXT): Remove, not used anymore.
+
 2012-07-14  Juanma Barranquero  <address@hidden>
 
        * s/ms-w32.h (GC_SETJMP_WORKS, GC_MARK_STACK): Set in nt/config.nt.

=== modified file 'src/gmalloc.c'
--- a/src/gmalloc.c     2012-07-05 18:35:48 +0000
+++ b/src/gmalloc.c     2012-07-14 10:03:30 +0000
@@ -1687,11 +1687,6 @@
    The author may be reached (Email) at the address address@hidden,
    or (US mail) as Mike Haertel c/o Free Software Foundation.  */
 
-/* Emacs defines GMALLOC_INHIBIT_VALLOC to avoid this definition
-   on MSDOS, where it conflicts with a system header file.  */
-
-#ifndef        GMALLOC_INHIBIT_VALLOC
-
 /* Allocate SIZE bytes on a page boundary.  */
 extern void *valloc (size_t);
 
@@ -1712,8 +1707,6 @@
   return memalign (pagesize, size);
 }
 
-#endif /* Not ELIDE_VALLOC.  */
-
 #ifdef GC_MCHECK
 
 /* Standard debugging hooks for `malloc'.

=== modified file 'src/s/msdos.h'
--- a/src/s/msdos.h     2012-06-11 23:17:11 +0000
+++ b/src/s/msdos.h     2012-07-14 10:03:30 +0000
@@ -31,7 +31,6 @@
 #endif
 
 #define DOS_NT /* MSDOS or WINDOWSNT */
-#undef BSD_SYSTEM
 
 /* subprocesses should be defined if you want to have code for
    asynchronous subprocesses (as used in M-x compile and M-x shell).
@@ -44,10 +43,6 @@
    different things on your system and must be used only through an
    encapsulation (which you should place, by convention, in sysdep.c).  */
 
-/* Avoid incompatibilities between gmalloc.c and system header files
-   in how to declare valloc.  */
-#define GMALLOC_INHIBIT_VALLOC
-
 /* This overrides the default value on editfns.c, since DJGPP
    does not have pw->pw_gecos.  */
 #define USER_FULL_NAME (getenv ("NAME"))
@@ -57,15 +52,16 @@
 #define _setjmp setjmp
 #define _longjmp longjmp
 
-#define DATA_START  (&etext + 1)
-
 #define _NAIVE_DOS_REGS
 
-/* command.com does not understand `...` so we define this.  */
+/* Used by emacs.c:decode_env_path.  */
 #define SEPCHAR ';'
 
+/* Used by callproc.c (and process.c, but in the part not compiled on
+   MSDOS).  The default is defined on process.h.  */
 #define NULL_DEVICE "nul"
 
+/* Used by floatfns.c.  */
 #define HAVE_INVERSE_HYPERBOLIC
 #define FLOAT_CHECK_DOMAIN
 
@@ -94,23 +90,14 @@
    likes that.  */
 #define FILE_SYSTEM_CASE Fmsdos_downcase_filename
 
-/* Define this to be the separator between devices and paths.  */
+/* Define this to be the separator between devices and paths.  Used by
+   lisp.h to define IS_DEVICE_SEP.  */
 #define DEVICE_SEP ':'
 
 /* We'll support either convention on MSDOG.  */
 #define IS_DIRECTORY_SEP(_c_) ((_c_) == '/' || (_c_) == '\\')
 #define IS_ANY_SEP(_c_) (IS_DIRECTORY_SEP (_c_) || IS_DEVICE_SEP (_c_))
 
-
-/* Mode line description of a buffer's type.  */
-#define MODE_LINE_BINARY_TEXT(buf) (NILP(B_(buf,buffer_file_type)) ? "T" : "B")
-
-/* We have (the code to control) a mouse.  */
-#define HAVE_MOUSE
-
-/* We can use mouse menus.  */
-#define HAVE_MENUS
-
 /* Define one of these for easier conditionals.  */
 #ifdef HAVE_X_WINDOWS
 /* We need a little extra space, see ../../lisp/loadup.el and the
@@ -129,7 +116,3 @@
    enlarging Emacs footprint by another 100+ KBytes.  */
 #define SYSTEM_PURESIZE_EXTRA (-170000+65000)
 #endif
-
-/* Tell the garbage collector that setjmp is known to save all
-   registers relevant for conservative garbage collection in the jmp_buf.  */
-#define GC_SETJMP_WORKS 1
@@ -94,23 +90,14 @@
 #define DEVICE_SEP ':'
 
-/* We'll support either convention on MSDOG.  */
+/* We'll support either convention of slashes on MSDOS.  */
 #define IS_DIRECTORY_SEP(_c_) ((_c_) == '/' || (_c_) == '\\')
 #define IS_ANY_SEP(_c_) (IS_DIRECTORY_SEP (_c_) || IS_DEVICE_SEP (_c_))


reply via email to

[Prev in Thread] Current Thread [Next in Thread]